@@ -1,10 +1,9 @@
 PieChart <-
-function(x, dframe=mydata, 
-         random.col=FALSE,
-         col.slices=NULL, col.low=NULL, col.hi=NULL,
+function(x, data=mydata, 
+         col.fill=NULL, col.low=NULL, col.hi=NULL,
          colors=c("rainbow", "terrain", "heat"),
-         text.out=TRUE, main=NULL,
-         pdf.file=NULL, pdf.width=5, pdf.height=5, ...) {
+         random.col=FALSE, main=NULL,
+         quiet=FALSE, pdf.file=NULL, pdf.width=5, pdf.height=5, ...) {
 
 
   if (missing(colors)) 
@@ -16,21 +15,22 @@ function(x, dframe=mydata,
   options(xname = x.name)
 
   # get data frame name
-  dframe.name <- deparse(substitute(dframe))
+  dname <- deparse(substitute(data))
+  options(dname = dname)
 
-  # get conditions and check for dframe existing
-  xs <- .xstatus(x.name, dframe.name)
+  # get conditions and check for data existing
+  xs <- .xstatus(x.name, dname)
   is.frml <- xs$ifr
   from.data <- xs$fd
   in.global <- xs$ig 
 
   # see if variable exists in the data frame, if x not in Global Env or function call 
-  if (!missing(x) && !in.global)  .xcheck(x.name, dframe.name, dframe)
+  if (!missing(x) && !in.global)  .xcheck(x.name, dname, data)
 
-  if (!in.global) x.call <- eval(substitute(dframe$x))
+  if (!in.global) x.call <- eval(substitute(data$x))
   else {  # vars that are function names get assigned to global
     x.call <- x
-    if (is.function(x.call)) x.call <- eval(substitute(dframe$x))
+    if (is.function(x.call)) x.call <- eval(substitute(data$x))
   }
 
   # set up graphics system
@@ -40,8 +40,8 @@ function(x, dframe=mydata,
   #on.exit(par(orig.params))
 
   .pc.main(x.call, 
-       random.col, col.slices, col.low, col.hi,
-       colors, text.out, main, 
+       random.col, col.fill, col.low, col.hi,
+       colors, quiet, main, 
        pdf.file, pdf.width, pdf.height, ...)
 
   # terminate pdf graphics system
