@@ -1,18 +1,18 @@
 Transform <-
-function (dframe=mydata, brief=FALSE, keep=TRUE, ...) {
+function(data=mydata, quiet=FALSE, ...) {
 
-  dname <- deparse(substitute(dframe))
+  dname <- deparse(substitute(data))
 
   # transformations done here into vector e, e[1] the first trans, etc.
-  e <- eval(substitute(list(...)), dframe, parent.frame())
+  e <- eval(substitute(list(...)), data, parent.frame())
 
   n.tvars <- length(e)
-  n.obs <- nrow(dframe)
+  n.obs <- nrow(data)
 
-  if (!brief) {
+  if (!quiet) {
     cat("\n")
     cat("Number of variables of", dname, "to transform:", n.tvars, "\n")
-    cat("Number of observations (rows) of ", dname, ": ", n.obs, "\n", sep="")
+    cat("Number of cases (rows) of ", dname, ": ", n.obs, "\n", sep="")
 
     cat("\n")
     .dash(69)
@@ -35,55 +35,51 @@ function (dframe=mydata, brief=FALSE, keep=TRUE, ...) {
       trs <- trs.all  # displayed later if only one transformation
   }
 
-  # vector of positions of existing vars in dframe, NA if not existing
-  inx <- match(names(e), names(dframe))
+  # vector of positions of existing vars in data, NA if not existing
+  inx <- match(names(e), names(data))
 
-  if (!brief) {
+  if (!quiet) {
     cat("\n")
     .dash(22)
     cat("Transformation Summary\n")
     .dash(22)
-    if (!no.break || n.tvars==1) {
-      for (i in 1:n.tvars) {
-        if (!is.na(inx[i])) txt <- "rewrite existing" else txt <- "      create new"
-        cat(txt, "variable: ", trs[i], "\n")
-      }
-    }
-    else {  # parsing too difficult, so just include variable names
+    #if (!no.break || n.tvars==1) {
+      #for (i in 1:n.tvars) {
+        #if (!is.na(inx[i])) txt <- "rewrite existing" else txt <- "      create new"
+        #cat(txt, "variable: ", trs[i], "\n")
+      #}
+    #}
+    #else {  # parsing too difficult, so just include variable names
        for (i in 1:n.tvars) {
         if (!is.na(inx[i])) txt <- "rewrite existing" else txt <- "      create new"
         cat(txt, "variable: ", names(e)[i], "\n")
       }
-    }
+    #}
   }
 
   # logical vector, TRUE if transformed var already exists, otherwise FALSE
   existing <- !is.na(inx)
 
-  # inx[existing], e[existing] gives only positions of existing vars in dframe
+  # inx[existing], e[existing] gives only positions of existing vars in data
   # corresponding FALSE values of existing are deleted
-  # add existing var transformations to dframe
+  # add existing var transformations to data
   if (any(existing))   # at least one existing var transformed
-    dframe[inx[existing]] <- e[existing]
+    data[inx[existing]] <- e[existing]
 
-  # add new var transformations to dframe
+  # add new var transformations to data
   if (!all(existing))  # at least one new var created
-    dframe <- do.call("data.frame", c(list(dframe), e[!existing]))
+    data <- do.call("data.frame", c(list(data), e[!existing]))
 
-  if (!brief) {
+  if (!quiet) {
     cat("\n\n")
     .dash(65)
     cat("After, First five rows of transformed data ")
-    if (keep) cat("for data frame:", dname)
     cat( "\n")
     .dash(65)
-    print(head(dframe[, names(e), drop=FALSE], n=5))
+    print(head(data[, names(e), drop=FALSE], n=5))
     cat("\n")
   }
-
-  if (keep) 
-    assign(dname, dframe, pos=.GlobalEnv)
-  else
-    return(dframe)
  
+  return(data)
+
 }
